@@ -53,7 +53,7 @@ Introduced in version 0.12, published on March 7, 2005.
 
 =head1 SEE ALSO
 
-L<Acme::MetaSyntactic>
+L<Acme::MetaSyntactic>.
 
 =cut
 
